package cn.gov.zjport.gtw.gateway.in.client;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.http.HttpEntity;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;

public class Client {

   protected String url;
   protected static final String APP_ID = "appId";
   protected static final String BIZ_CODE = "bizCode";
   protected static final String BIZ_ID = "bizId";
   protected static final String CONTENT = "content";
   protected static final String TIMESTAMP = "timestamp";
   protected static final String VERSION = "version";
   protected static final String SIGN = "sign";
   protected static final String APP_KEY = "appKey";


   public Client(String url) {
      this.url = url;
   }

   public String post(String appId, String bizCode, String bizId, String content, String timestamp, String sign) {
      return this.post(appId, bizCode, bizId, content, timestamp, sign, 10000, 3000);
   }

   public String post(String appId, String bizCode, String bizId, String content, String timestamp, String sign, int socketTimeout, int connectTimeout) {
      CloseableHttpClient httpClient = this.getHttpClient();
      HttpPost httppost = new HttpPost(this.url);
      ArrayList formparams = new ArrayList();
      formparams.add(new BasicNameValuePair("appId", appId));
      formparams.add(new BasicNameValuePair("bizCode", bizCode));
      formparams.add(new BasicNameValuePair("bizId", bizId));
      formparams.add(new BasicNameValuePair("content", content));
      formparams.add(new BasicNameValuePair("timestamp", timestamp));
      formparams.add(new BasicNameValuePair("sign", sign));

      String var16;
      try {
         UrlEncodedFormEntity e = new UrlEncodedFormEntity(formparams, "UTF-8");
         httppost.setEntity(e);
         RequestConfig requestConfig = RequestConfig.custom().setSocketTimeout(socketTimeout).setConnectTimeout(connectTimeout).build();
         httppost.setConfig(requestConfig);
         CloseableHttpResponse response = httpClient.execute(httppost);
         HttpEntity entity = response.getEntity();
         if(entity == null) {
            return null;
         }

         var16 = EntityUtils.toString(entity, "UTF-8");
      } catch (ClientProtocolException var31) {
         var31.printStackTrace();
         return null;
      } catch (UnsupportedEncodingException var32) {
         var32.printStackTrace();
         return null;
      } catch (Exception var33) {
         var33.printStackTrace();
         return null;
      } finally {
         try {
            httpClient.close();
         } catch (IOException var30) {
            var30.printStackTrace();
         }

      }

      return var16;
   }

   public String getSign(String bizCode, String bizId, String content, String timestamp, String appKey) {
      StringBuffer buffer = new StringBuffer();
      buffer.append("bizCode");
      buffer.append("=");
      buffer.append(bizCode);
      buffer.append("&");
      buffer.append("bizId");
      buffer.append("=");
      buffer.append(bizId);
      buffer.append("&");
      buffer.append("content");
      buffer.append("=");
      buffer.append(content);
      buffer.append("&");
      buffer.append("timestamp");
      buffer.append("=");
      buffer.append(timestamp);
      buffer.append("&");
      buffer.append("appKey");
      buffer.append("=");
      buffer.append(appKey);
      return DigestUtils.shaHex(buffer.toString());
   }

   public void setUrl(String url) {
      this.url = url;
   }

   public CloseableHttpClient getHttpClient() {
      return HttpClients.createDefault();
   }

   public static void main(String[] args) {
      Client client = new Client("https://openapi-test.zjport.gov.cn:8553/gateway/receive");
      String appId = "10010000";
      String bizCode = "JKF00002";
      String bizId = "12";
      String content = "业务报文内容";
      String timestamp = String.valueOf(System.currentTimeMillis());
      String appKey = "abcdefghij1234567890abcdefghij1234567890";
      String sign = client.getSign(bizCode, bizId, content, timestamp, appKey);
      String result = client.post(appId, bizCode, bizId, content, timestamp, sign);
      System.out.println(result);
   }
}
